@@ -1143,7 +1143,7 @@ plot.medsens <- function(x, sens.par = c("rho", "R2"),
                     else main0 <- main
                     contour(R2M, R2Y, d0mat.p, levels=levels0, main=main0, 
                             xlab=xlab, ylab=ylab, ylim=ylim, xlim=xlim, lwd=lwd,...)
-                    contour(R2M, R2Y, d0mat.p, levels=0, lwd=lwd+1, add=TRUE)
+                    contour(R2M, R2Y, d0mat.p, levels=0, lwd=lwd+1, add=TRUE, drawlabels=FALSE)
                 } else {
                     d0.n <- rev(approx(x$d0[1:((length(x$d0)+1)/2)], n=dlength)$y)
                     d0mat.n <- matrix(d0.n[Rprod.mat/0.0001+1], nrow=length(R2M))
@@ -1158,8 +1158,8 @@ plot.medsens <- function(x, sens.par = c("rho", "R2"),
                                             (lambda[2]*lambda[3])==-1))
                     else main0 <- main
                     contour(R2M, R2Y, d0mat.n, levels=levels0, main=main0, 
-                            xlab=xlab, ylab=ylab, ylim=ylim, xlim=xlim, lwd=lwd,...)
-                    contour(R2M, R2Y, d0mat.n, levels=0, lwd=lwd+1, add=TRUE)
+                            xlab=xlab, ylab=ylab, ylim=ylim, xlim=xlim, lwd=lwd, ...)
+                    contour(R2M, R2Y, d0mat.n, levels=0, lwd=lwd+1, add=TRUE, drawlabels=FALSE)
                 }
                 if(is.null(xlab) & r.type == "residual")
                     title(xlab=expression(paste(R[M]^{2},"*")), line=2.5, cex.lab=.9)
@@ -1191,7 +1191,7 @@ plot.medsens <- function(x, sens.par = c("rho", "R2"),
                     else main1 <- main
                     contour(R2M, R2Y, d1mat.p, levels=levels1, main=main1, 
                             xlab=xlab, ylab=ylab, ylim=ylim, xlim=xlim, lwd=lwd, ...)
-                    contour(R2M, R2Y, d1mat.p, levels=0, lwd=lwd+1, add=TRUE)
+                    contour(R2M, R2Y, d1mat.p, levels=0, lwd=lwd+1, add=TRUE, drawlabels=FALSE)
                 } else {
                     d1.n <- rev(approx(x$d1[1:((length(x$d1)+1)/2)], n=dlength)$y)
                     d1mat.n <- matrix(d1.n[Rprod.mat/0.0001+1], nrow=length(R2M))
@@ -1207,7 +1207,7 @@ plot.medsens <- function(x, sens.par = c("rho", "R2"),
                     else main1 <- main
                     contour(R2M, R2Y, d1mat.n, levels=levels1, main=main1, 
                             xlab=xlab, ylab=ylab, ylim=ylim, xlim=xlim, lwd=lwd, ...)
-                    contour(R2M, R2Y, d1mat.n, levels=0, lwd=lwd+1, add=TRUE)
+                    contour(R2M, R2Y, d1mat.n, levels=0, lwd=lwd+1, add=TRUE, drawlabels=FALSE)
                 }
                 if(is.null(xlab) & r.type == "residual")
                     title(xlab=expression(paste(R[M]^{2},"*")), line=2.5, cex.lab=.9)
@@ -1241,7 +1241,7 @@ plot.medsens <- function(x, sens.par = c("rho", "R2"),
                     else main0 <- main
                     contour(R2M, R2Y, z0mat.p, levels=levels0, main=main0, 
                             xlab=xlab, ylab=ylab, ylim=ylim, xlim=xlim, lwd=lwd,...)
-                    contour(R2M, R2Y, z0mat.p, levels=0, lwd=lwd+1, add=TRUE)
+                    contour(R2M, R2Y, z0mat.p, levels=0, lwd=lwd+1, add=TRUE, drawlabels=FALSE)
                 } else {
                     z0.n <- rev(approx(x$z0[1:((length(x$z0)+1)/2)], n=dlength)$y)
                     z0mat.n <- matrix(z0.n[Rprod.mat/0.0001+1], nrow=length(R2M))
@@ -1257,7 +1257,7 @@ plot.medsens <- function(x, sens.par = c("rho", "R2"),
                     else main0 <- main
                     contour(R2M, R2Y, z0mat.n, levels=levels0, main=main0, 
                             xlab=xlab, ylab=ylab, ylim=ylim, xlim=xlim, lwd=lwd,...)
-                    contour(R2M, R2Y, z0mat.n, levels=0, lwd=lwd+1, add=TRUE)
+                    contour(R2M, R2Y, z0mat.n, levels=0, lwd=lwd+1, add=TRUE, drawlabels=FALSE)
                 }
                 if(is.null(xlab) & r.type == "residual")
                     title(xlab=expression(paste(R[M]^{2},"*")), line=2.5, cex.lab=.9)
@@ -1289,7 +1289,7 @@ plot.medsens <- function(x, sens.par = c("rho", "R2"),
                     else main1 <- main
                     contour(R2M, R2Y, z1mat.p, levels=levels1, main=main1, 
                             xlab=xlab, ylab=ylab, ylim=ylim, xlim=xlim, lwd=lwd, ...)
-                    contour(R2M, R2Y, z1mat.p, levels=0, lwd=lwd+1, add=TRUE)
+                    contour(R2M, R2Y, z1mat.p, levels=0, lwd=lwd+1, add=TRUE, drawlabels=FALSE)
                 } else {
                     z1.n <- rev(approx(x$z1[1:((length(x$z1)+1)/2)], n=dlength)$y)
                     z1mat.n <- matrix(z1.n[Rprod.mat/0.0001+1], nrow=length(R2M))
@@ -1305,7 +1305,7 @@ plot.medsens <- function(x, sens.par = c("rho", "R2"),
                     else main1 <- main
                     contour(R2M, R2Y, z1mat.n, levels=levels1, main=main1, 
                             xlab=xlab, ylab=ylab, ylim=ylim, xlim=xlim, lwd=lwd, ...)
-                    contour(R2M, R2Y, z1mat.n, levels=0, lwd=lwd+1, add=TRUE)
+                    contour(R2M, R2Y, z1mat.n, levels=0, lwd=lwd+1, add=TRUE, drawlabels=FALSE)
                 }
                 if(is.null(xlab) & r.type == "residual")
                     title(xlab=expression(paste(R[M]^{2},"*")), line=2.5, cex.lab=.9)
@@ -1340,7 +1340,7 @@ plot.medsens <- function(x, sens.par = c("rho", "R2"),
                     else main0 <- main
                     contour(R2M, R2Y, d0mat.p, levels=levels0, main=main0, 
                             xlab=xlab, ylab=ylab, ylim=ylim, xlim=xlim, lwd=lwd,...)
-                    contour(R2M, R2Y, d0mat.p, levels=0, lwd=lwd+1, add=TRUE)
+                    contour(R2M, R2Y, d0mat.p, levels=0, lwd=lwd+1, add=TRUE, drawlabels=FALSE)
                 } else {
                     d0.n <- rev(approx(x$d0[1:((length(x$d0)+1)/2)], n=dlength)$y)
                     d0mat.n <- matrix(d0.n[Rprod.mat/0.0001+1], nrow=length(R2M))
@@ -1356,7 +1356,7 @@ plot.medsens <- function(x, sens.par = c("rho", "R2"),
                     else main0 <- main
                     contour(R2M, R2Y, d0mat.n, levels=levels0, main=main0, 
                             xlab=xlab, ylab=ylab, ylim=ylim, xlim=xlim, lwd=lwd,...)
-                    contour(R2M, R2Y, d0mat.n, levels=0, lwd=lwd+1, add=TRUE)
+                    contour(R2M, R2Y, d0mat.n, levels=0, lwd=lwd+1, add=TRUE, drawlabels=FALSE)
                 }
                 if(is.null(xlab) & r.type == "residual")
                     title(xlab=expression(paste(R[M]^{2},"*")), line=2.5, cex.lab=.9)
@@ -1389,7 +1389,7 @@ plot.medsens <- function(x, sens.par = c("rho", "R2"),
                     else main0 <- main
                     contour(R2M, R2Y, z0mat.p, levels=levels0, main=main0, 
                             xlab=xlab, ylab=ylab, ylim=ylim, xlim=xlim, lwd=lwd,...)
-                    contour(R2M, R2Y, z0mat.p, levels=0, lwd=lwd+1, add=TRUE)
+                    contour(R2M, R2Y, z0mat.p, levels=0, lwd=lwd+1, add=TRUE, drawlabels=FALSE)
                 } else {
                     z0.n <- rev(approx(x$z0[1:((length(x$z0)+1)/2)], n=dlength)$y)
                     z0mat.n <- matrix(z0.n[Rprod.mat/0.0001+1], nrow=length(R2M))
@@ -1405,7 +1405,7 @@ plot.medsens <- function(x, sens.par = c("rho", "R2"),
                     else main0 <- main
                     contour(R2M, R2Y, z0mat.n, levels=levels0, main=main0, 
                             xlab=xlab, ylab=ylab, ylim=ylim, xlim=xlim, lwd=lwd,...)
-                    contour(R2M, R2Y, z0mat.n, levels=0, lwd=lwd+1, add=TRUE)
+                    contour(R2M, R2Y, z0mat.n, levels=0, lwd=lwd+1, add=TRUE, drawlabels=FALSE)
                 }
                 if(is.null(xlab) & r.type == "residual")
                     title(xlab=expression(paste(R[M]^{2},"*")), line=2.5, cex.lab=.9)
